California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 039 - TAX TREATMENT FOR MULTISTATE BUSINESSES. CLEAN ENERGY AND ENERGY EFFICIENCY FUNDING. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1328039 | CALIFORNIA MANUFACTURERS & TECHNOLOGY ASSOCIATION (CMTA) ISSUES POLITICAL ACTION COMMITTEE (PAC) NO ON 39 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1352904 | BLUEGREEN ALLIANCE, INC. COMMITTEE FOR PROPOSITION 39 SUPPORTED BY ENVIRONMENTALISTS AND LABOR UNIONS, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | CALIFORNIANS FOR INFORMED VOTING - YES ON 30, 34, 35, 36, 37, AND 39 AND NO ON 31 AND 32 SPONSORED BY BALLOT INITIATIVE STRATEGY CENTER | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1348995 | ASIAN PACIFIC ENVIRONMENTAL NETWORK (APEN) ACTION'S YES ON 30 & 39, NO ON 32 COMMITTEE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1343760 | SOUTH LA POWER PAC | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1344009 | YES ON 39 - CALIFORNIANS TO CLOSE THE OUT-OF-STATE CORPORATE TAX LOOPHOLE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1350885 | MI FAMILIA VOTA - YES ON 30 AND 39 FOR TAX FAIRNESS AND NO ON 32 TO STOP SPECIAL EXEMPTIONS FOR CORPORATE POLITICAL SPENDING, SPONSORED BY THE CALIFORNIA STATE COUNCIL OF SERVICE EMPLOYEES | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1324059 | CALIFORNIANS FOR CLEAN ENERGY AND JOBS, SPONSORED BY ENVIRONMENTAL ORGANIZATIONS AND BUSINESS FOR CLEAN ENERGY AND JOBS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288513 | CALIFORNIANS FOR CLEAN ENERGY AND JOBS - YES ON PROPOSITION 39, SPONSORED BY CALIFORNIA LEAGUE OF CONSERVATION VOTERS | SUPPORT